<template>
    <div class="app-container">
        <div style="margin: 15px">
            <span class="span-filter-label">作业编号：</span>
            <el-input style="width: 160px" v-model="filter.filter.taskcode"></el-input>
            <span class="span-filter-label">隐患等级</span>
            <el-select v-model="filter.filter.level"  placeholder="请选择">
                <el-option
                    v-for="item in levels"
                    :key="item.key"
                    :label="item.value"
                    :value="item.key">
                </el-option>
            </el-select>
            <span class="span-filter-label">负责人</span>
            <el-input style="width: 160px" v-model="filter.filter.requestor"></el-input>
            <span class="span-filter-label">整改人</span>
            <el-input style="width: 160px" v-model="filter.filter.supervisor"></el-input>
            <el-button class="filter-item" style="margin-left: 10px;" type="primary" icon="el-icon-search"
                       @click="queryHandle"/>
        </div>
        <div class="table_content">
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="tableData"
                border
                fit
                highlight-current-row
                style="width: 100%;"
            >
                <el-table-column type="index" label="序号" align="center" width="80"/>
                <el-table-column label="状态" prop="status" align="center" />
                <el-table-column label="作业编号" prop="taskcode" align="center" />
                <el-table-column label="隐患等级" prop="level" align="center" >
                    <template slot-scope="scope">
                        <el-tag :type="scope.row.level == '紧急'?'danger':'warning'">{{scope.row.level}}</el-tag>
                    </template>
                </el-table-column>
                <el-table-column label="上报人" prop="requestor" align="center" />
                <el-table-column label="负责人" prop="principal" align="center" />
                <el-table-column label="整改" prop="supervisor" align="center" />

                <el-table-column label="创建时间" prop="createtime" align="center" />
                <el-table-column label="操作" align="center" width="240" class-name="small-padding fixed-width">
                    <template slot-scope="scope">
                        <el-button  type="text" @click="viewHandle(scope.row)">查看</el-button>
                        <el-button  type="text" @click="confirmHandle(scope.row)" v-if="scope.row.status === '未确认'">上报确认</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br>
            <el-pagination
                v-show="recordTotal>0"
                :current-page="currentPage"
                :page-sizes="[10, 20, 30, 50]"
                :page-size="pageSize"
                :total="recordTotal"
                layout="total, sizes, prev, pager, next, jumper"
                background
                style="float:right;"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
            />
        </div>
        <el-dialog :title="dialogStatus==='confirm'?'上报确认':'查看'" :visible.sync="dialogFormVisible"
                   :modal-append-to-body="false" :close-on-click-modal="false" width="800px">
            <el-form ref="dataForm" :rules="dataFormRules" :model="dataForm" label-position="right" label-width="140px"
                     style="" element-loading-text="保存中...">

                <el-form-item label="作业编号：">
                    <el-select v-model="dataForm.taskid" filterable placeholder="请选择" :disabled="isView">
                        <el-option
                            v-for="item in tasksInfo"
                            :key="item.id"
                            :label="item.code"
                            :value="item.id">
                        </el-option>
                    </el-select>
                </el-form-item>

                <el-form-item label="隐患级别：">
                    <el-select v-model="dataForm.level"  placeholder="请选择" :disabled="isView">
                        <el-option
                            v-for="item in levels"
                            :key="item.key"
                            :label="item.value"
                            :value="item.key">
                        </el-option>
                    </el-select>
                </el-form-item>

                <el-form-item label="上报说明：" >
                    <el-input
                        style="width: 400px"
                        type="textarea"
                        :rows="3"
                        :disabled="isView"
                        placeholder="请输入内容"
                        v-model="dataForm.note">
                    </el-input>
                </el-form-item>

                <el-form-item label="上报图片：" v-if="!isView">
                    <el-upload
                        ref="upload"
                        :action="baseUrl"
                        :auto-upload="false"
                        :headers="headers"
                        :on-change="handleChange"
                        name="file"
                        :file-list="fileList"
                        list-type="picture-card"
                        multiple
                    >
                        <i class="el-icon-plus"></i>
                    </el-upload>

                </el-form-item>

                <el-form-item label="上报图片:" v-if="isView && imgUrls.length > 0" >
                    <el-image
                        class="upload-img"
                        v-for='item in imgUrls'
                        :key='item.id'
                        :src="item.url"
                        :preview-src-list="imgPreviewUrls"
                        style="width:200px;height: 200px;margin: 10px;"
                    >
                    </el-image>
                </el-form-item>

                <el-form-item label="隐患确认：" >
                        <el-radio v-model="dataForm.ishiddendanger" label="1" border >是隐患</el-radio>
                        <el-radio v-model="dataForm.ishiddendanger" label="0" border >非隐患</el-radio>
                </el-form-item>

                <el-form-item label="确认说明："  >
                    <el-input
                        style="width: 400px"
                        type="textarea"
                        :rows="3"
                        placeholder="请输入内容"
                        v-model="dataForm.confirmnote">
                    </el-input>
                </el-form-item>



            </el-form>

            <div style="margin-top: 20px;margin-left: 140px;"  class="dialog-footer" >
                <el-button @click="dialogFormVisible = false">取消</el-button>
                <el-button type="primary" @click="trigger2Submit(dataForm.id)">隐患确认</el-button>
            </div>

        </el-dialog>
        <report-view ref="reportView"></report-view>


        <div style="clear: both;"></div>
    </div>
</template>

<script>
import { checkBtnPermission} from "@/utils/permission";
import { getSelectTask,hiddenDangerConfirm ,hiddenDangerConfirmList} from '@/api/hiddenDanger';
import { getToken} from "@/utils/auth";
import reportView from "./reportView/reportView";
import { param } from '../../utils'

export default {
    name: "confirm",
  components: {
    reportView
  },
    data() {
      return {
        baseUrl: process.env.BASE_API + 'hiddenDanger/report',
        headers: {
          'Authorization': getToken()
        },
        tasksInfo: [],
        imgUrls:[],
        imgPreviewUrls:[],
        isView:false,
        isConfirm:false,
        confirmShow:false,
        isRectify:false,
        fileList: [],
        pageSize: 10,
        recordTotal: 0,
        currentPage: 1,
        pageTotal: 0,
        tableKey: 0,
        tableData:[],
        helpDocData: null,
        listLoading: true,
        levels:[
          {"key":"URGENT","value":"紧急"},
          {"key":"COMMON","value":"一般"},
        ],
        dataForm: {
          id:'',
          taskid: '',
          note: '',
          level:'',
          confirmnote:'',
          ishiddendanger:''
        },
        queryForm: {
          name: ''
        },
        dialogFormVisible: false,
        dialogStatus: '',
        dataFormRules: {},
        fileType: [],
        productVoList: [],
        productVoDialogVisible: false,

        productDialogFormVisible: false,
        productData: [],
        pageSizeProduct: 10,
        currentPageProduct: 1,
        recordTotalProduct: 0,
        pageTotalProduct: 0,
        queryProductForm: {
          name: '',
          manufacturer: '',
          directionCode: '',
          type: ''
        },
        isSupervision: '',

        manufacturer: '',
        enterpriseList: [],
        enterpriseDialogFormVisible: false,
        pageSizeEnterpise: 10,
        currentPageEnterpise: 1,
        recordTotalEnterpise: 0,
        pageTotalEnterpise: 0,
        filter:{
          pageIndex:1,
          pageSize:10,
          filter:{
            taskcode:'',
            supervisor:'',
            requestor:'',
            level:""
          }
        }
      }
    },
    created() {
      this.hiddenDangerList();

    },
    computed: {

    },
    methods: {
        refreshHandle: function () {
            this.hiddenDangerList()
        },
        queryHandle: function () {
            this.currentPage = 1
            this.hiddenDangerList()
        },
        resetDataForm() {
            this.dataForm = {
              dataForm: {
                taskid: '',
                taskcode:'',
                note: '',
                level:''
              }
            }
        },
        showCreateHandle() {
          this.getSelectTasks()
            this.resetDataForm()
            this.dialogStatus = 'create'
            this.isView = false
            this.dialogFormVisible = true
            this.$nextTick(() => {
                this.$refs['dataForm'].clearValidate()
            })
        },
        viewHandle: function (row) {

          this.$refs.reportView.showDialog("查看",row)

        },
      confirmHandle:function(row){
            this.resetDataForm();
            this.dialogStatus = 'confirm';
            this.isView = true
            this.confirmShow = true;
            this.dataForm.id = row.id
            this.dataForm.taskid = row.taskcode
            this.dataForm.level = row.level;
            this.dataForm.note = row.createnote;
            this.imgUrls = row.reportResources.map(item=>{return {url:process.env.IMG_API+item.url,name:item.id}})
            this.imgPreviewUrls = row.reportResources.map(item=>{ return process.env.IMG_API + item.url })
            this.dialogFormVisible = true;
      },
        handleSizeChange: function (val) {
            this.pageSize = val
            this.currentPage = 1
            this.hiddenDangerList()
        },
        handleCurrentChange: function (val) {
            this.currentPage = val
            this.hiddenDangerList()
        },
        getBtnPermission(btnType) {
            return checkBtnPermission(this.userType, btnType)
        },

        showProductHandle(){
            this.productDialogFormVisible = true;
        },
        showEnterprise(){
            this.enterpriseDialogFormVisible = true;
        },
        downloadHandle(fileurl){
            window.open(fileurl, '_blank');
        },



        getSelectTasks(){
          getSelectTask()
            .then(res=>{
              if (res.status !== 200)
                this.$message({
                  message: '接口错误',
                  type: 'success'
                });
              else{
                this.tasksInfo = res.data.result.map(item=>{return {"id":item.id,"code":item.code}})
              }
            })

            .catch(res=>{
              console.log(res)
            })
        },

      handleChange(file, fileList) {
        this.fileList = fileList
      },

      trigger2Submit(){
        let params = {}
        params['id'] = this.dataForm.id
        params['note'] = this.dataForm.confirmnote
        params['ishiddendanger'] = this.dataForm.ishiddendanger

        hiddenDangerConfirm(params).then(res=>{
          if (res.status === 200) {
            if (res.data.code === '200') {
              this.dialogFormVisible = false
              this.$message({
                message: '操作成功',
                type: 'success'
              });
              this.hiddenDangerList()
            }else{
              this.$message({
                message: res.data.message,
                type: 'success'
              });
            }
            this.fileList = []

          }
          else{
            this.$message({
              message: '接口错误',
              type: 'warning'
            });
          }
          }
        )
      },

      hiddenDangerList(){
        hiddenDangerConfirmList(this.filter).then(res=>{
          this.listLoading = false
          if (res.status === 200) {
            if (res.data.code === '200') {
              this.tableData =  res.data.result.records
            }
          }else{
            this.$message({
              message: '接口错误',
              type: 'warning'
            });

          }
        })
      },

    }
}
</script>

<style scoped>

</style>
